@@ -138,7 +138,7 @@ bool straceWin::makeRelativePath(const QString& dir, QString& file)
 
 QString straceWin::getSourcePathAndLineNumber(HANDLE hProcess, DWORD64 addr)
 {
-    IMAGEHLP_LINE64 line = {0};
+    IMAGEHLP_LINE64 line {};
     line.SizeOfStruct = sizeof(IMAGEHLP_LINE64);
     DWORD dwDisplacement = 0;
 
@@ -291,7 +291,7 @@ const QString straceWin::getBacktrace()
                 demangle(funcName);
 #endif
 
-                // now ihsf.InstructionOffset points to the instruction that follows CALL instuction
+                // now ihsf.InstructionOffset points to the instruction that follows CALL instruction
                 // decrease the query address by one byte to point somewhere in the CALL instruction byte sequence
                 sourceFile = getSourcePathAndLineNumber(hProcess, ihsf.InstructionOffset - 1);
             }
