@@ -1,6 +1,6 @@
 /*
  * Bittorrent Client using Qt and libtorrent.
- * Copyright (C) 2010  Christophe Dumez
+ * Copyright (C) 2010  Christophe Dumez <chris@qbittorrent.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -24,8 +24,6 @@
  * modify file(s), you may extend this exception to your version of the file(s),
  * but you are not obligated to do so. If you do not wish to do so, delete this
  * exception statement from your version.
- *
- * Contact : chris@qbittorrent.org
  */
 
 #ifndef BITTORRENT_TORRENTCREATORTHREAD_H
@@ -36,18 +34,30 @@
 
 namespace BitTorrent
 {
+    struct TorrentCreatorParams
+    {
+        bool isPrivate;
+        bool isAlignmentOptimized;
+        int pieceSize;
+        QString inputPath;
+        QString savePath;
+        QString comment;
+        QString source;
+        QStringList trackers;
+        QStringList urlSeeds;
+    };
+
     class TorrentCreatorThread : public QThread
     {
         Q_OBJECT
 
     public:
-        TorrentCreatorThread(QObject *parent = 0);
+        TorrentCreatorThread(QObject *parent = nullptr);
         ~TorrentCreatorThread();
 
-        void create(const QString &inputPath, const QString &savePath, const QStringList &trackers,
-                    const QStringList &urlSeeds, const QString &comment, bool isPrivate, int pieceSize);
+        void create(const TorrentCreatorParams &params);
 
-        static int calculateTotalPieces(const QString &inputPath, const int pieceSize);
+        static int calculateTotalPieces(const QString &inputPath, const int pieceSize, const bool isAlignmentOptimized);
 
     protected:
         void run();
@@ -58,15 +68,9 @@ namespace BitTorrent
         void updateProgress(int progress);
 
     private:
-        void sendProgressSignal(int numHashes, int numPieces);
+        void sendProgressSignal(int currentPieceIdx, int totalPieces);
 
-        QString m_inputPath;
-        QString m_savePath;
-        QStringList m_trackers;
-        QStringList m_urlSeeds;
-        QString m_comment;
-        bool m_private;
-        int m_pieceSize;
+        TorrentCreatorParams m_params;
     };
 }
 
