@@ -97,16 +97,23 @@ void Server::incomingConnection(qintptr socketDescriptor)
 #endif
 
     Connection *c = new Connection(serverSocket, m_requestHandler, this);
-    m_connections.append(c);
+    m_connections.insert(c);
+    connect(serverSocket, &QAbstractSocket::disconnected, this, [c, this]() { removeConnection(c); });
+}
+
+void Server::removeConnection(Connection *connection)
+{
+    m_connections.remove(connection);
+    connection->deleteLater();
 }
 
 void Server::dropTimedOutConnection()
 {
-    QMutableListIterator<Connection *> i(m_connections);
+    QMutableSetIterator<Connection *> i(m_connections);
     while (i.hasNext()) {
-        auto connection = i.next();
-        if (connection->isClosed() || connection->hasExpired(KEEP_ALIVE_DURATION)) {
-            delete connection;
+        Connection *connection = i.next();
+        if (connection->hasExpired(KEEP_ALIVE_DURATION)) {
+            connection->deleteLater();
             i.remove();
         }
     }
