@@ -43,7 +43,6 @@
 
 #ifdef Q_OS_WIN
 #include <shlobj.h>
-#include <winreg.h>
 #include <QRegularExpression>
 #endif
 
@@ -51,6 +50,7 @@
 #include <CoreServices/CoreServices.h>
 #endif
 
+#include "global.h"
 #include "logger.h"
 #include "settingsstorage.h"
 #include "utils/fs.h"
@@ -92,7 +92,8 @@ void Preferences::setValue(const QString &key, const QVariant &value)
 // General options
 QString Preferences::getLocale() const
 {
-    return value("Preferences/General/Locale", QLocale::system().name()).toString();
+    const QString localeName = value("Preferences/General/Locale").toString();
+    return (localeName.isEmpty() ? QLocale::system().name() : localeName);
 }
 
 void Preferences::setLocale(const QString &locale)
@@ -212,7 +213,7 @@ void Preferences::setCloseToTrayNotified(bool b)
 {
     setValue("Preferences/General/CloseToTrayNotified", b);
 }
-#endif
+#endif // Q_OS_MAC
 
 bool Preferences::isToolbarDisplayed() const
 {
@@ -293,7 +294,7 @@ void Preferences::setWinStartup(bool b)
         settings.remove("qBittorrent");
     }
 }
-#endif
+#endif // Q_OS_WIN
 
 // Downloads
 QString Preferences::lastLocationPath() const
@@ -505,7 +506,7 @@ void Preferences::setWebUiAuthSubnetWhitelistEnabled(bool enabled)
 QList<Utils::Net::Subnet> Preferences::getWebUiAuthSubnetWhitelist() const
 {
     QList<Utils::Net::Subnet> subnets;
-    foreach (const QString &rawSubnet, value("Preferences/WebUI/AuthSubnetWhitelist").toStringList()) {
+    for (const QString &rawSubnet : asConst(value("Preferences/WebUI/AuthSubnetWhitelist").toStringList())) {
         bool ok = false;
         const Utils::Net::Subnet subnet = Utils::Net::parseSubnet(rawSubnet.trimmed(), &ok);
         if (ok)
@@ -626,6 +627,16 @@ void Preferences::setWebUiCSRFProtectionEnabled(bool enabled)
     setValue("Preferences/WebUI/CSRFProtection", enabled);
 }
 
+bool Preferences::isWebUIHostHeaderValidationEnabled() const
+{
+    return value("Preferences/WebUI/HostHeaderValidation", true).toBool();
+}
+
+void Preferences::setWebUIHostHeaderValidationEnabled(const bool enabled)
+{
+    setValue("Preferences/WebUI/HostHeaderValidation", enabled);
+}
+
 bool Preferences::isWebUiHttpsEnabled() const
 {
     return value("Preferences/WebUI/HTTPS/Enabled", false).toBool();
@@ -878,153 +889,6 @@ void Preferences::disableRecursiveDownload(bool disable)
 }
 
 #ifdef Q_OS_WIN
-namespace
-{
-    enum REG_SEARCH_TYPE
-    {
-        USER,
-        SYSTEM_32BIT,
-        SYSTEM_64BIT
-    };
-
-    QStringList getRegSubkeys(HKEY handle)
-    {
-        QStringList keys;
-
-        DWORD cSubKeys = 0;
-        DWORD cMaxSubKeyLen = 0;
-        LONG res = ::RegQueryInfoKeyW(handle, NULL, NULL, NULL, &cSubKeys, &cMaxSubKeyLen, NULL, NULL, NULL, NULL, NULL, NULL);
-
-        if (res == ERROR_SUCCESS) {
-            ++cMaxSubKeyLen; // For null character
-            LPWSTR lpName = new WCHAR[cMaxSubKeyLen];
-            DWORD cName;
-
-            for (DWORD i = 0; i < cSubKeys; ++i) {
-                cName = cMaxSubKeyLen;
-                res = ::RegEnumKeyExW(handle, i, lpName, &cName, NULL, NULL, NULL, NULL);
-                if (res == ERROR_SUCCESS)
-                    keys.push_back(QString::fromWCharArray(lpName));
-            }
-
-            delete[] lpName;
-        }
-
-        return keys;
-    }
-
-    QString getRegValue(HKEY handle, const QString &name = QString())
-    {
-        QString result;
-
-        DWORD type = 0;
-        DWORD cbData = 0;
-        LPWSTR lpValueName = NULL;
-        if (!name.isEmpty()) {
-            lpValueName = new WCHAR[name.size() + 1];
-            name.toWCharArray(lpValueName);
-            lpValueName[name.size()] = 0;
-        }
-
-        // Discover the size of the value
-        ::RegQueryValueExW(handle, lpValueName, NULL, &type, NULL, &cbData);
-        DWORD cBuffer = (cbData / sizeof(WCHAR)) + 1;
-        LPWSTR lpData = new WCHAR[cBuffer];
-        LONG res = ::RegQueryValueExW(handle, lpValueName, NULL, &type, (LPBYTE)lpData, &cbData);
-        if (lpValueName)
-            delete[] lpValueName;
-
-        if (res == ERROR_SUCCESS) {
-            lpData[cBuffer - 1] = 0;
-            result = QString::fromWCharArray(lpData);
-        }
-        delete[] lpData;
-
-        return result;
-    }
-
-    QString pythonSearchReg(const REG_SEARCH_TYPE type)
-    {
-        HKEY hkRoot;
-        if (type == USER)
-            hkRoot = HKEY_CURRENT_USER;
-        else
-            hkRoot = HKEY_LOCAL_MACHINE;
-
-        REGSAM samDesired = KEY_READ;
-        if (type == SYSTEM_32BIT)
-            samDesired |= KEY_WOW64_32KEY;
-        else if (type == SYSTEM_64BIT)
-            samDesired |= KEY_WOW64_64KEY;
-
-        QString path;
-        LONG res = 0;
-        HKEY hkPythonCore;
-        res = ::RegOpenKeyExW(hkRoot, L"SOFTWARE\\Python\\PythonCore", 0, samDesired, &hkPythonCore);
-
-        if (res == ERROR_SUCCESS) {
-            QStringList versions = getRegSubkeys(hkPythonCore);
-            qDebug("Python versions nb: %d", versions.size());
-            versions.sort();
-
-            bool found = false;
-            while (!found && !versions.empty()) {
-                const QString version = versions.takeLast() + "\\InstallPath";
-                LPWSTR lpSubkey = new WCHAR[version.size() + 1];
-                version.toWCharArray(lpSubkey);
-                lpSubkey[version.size()] = 0;
-
-                HKEY hkInstallPath;
-                res = ::RegOpenKeyExW(hkPythonCore, lpSubkey, 0, samDesired, &hkInstallPath);
-                delete[] lpSubkey;
-
-                if (res == ERROR_SUCCESS) {
-                    qDebug("Detected possible Python v%s location", qUtf8Printable(version));
-                    path = getRegValue(hkInstallPath);
-                    ::RegCloseKey(hkInstallPath);
-
-                    if (!path.isEmpty() && QDir(path).exists("python.exe")) {
-                        qDebug("Found python.exe at %s", qUtf8Printable(path));
-                        found = true;
-                    }
-                }
-            }
-
-            if (!found)
-                path = QString();
-
-            ::RegCloseKey(hkPythonCore);
-        }
-
-        return path;
-    }
-}
-
-QString Preferences::getPythonPath()
-{
-    QString path = pythonSearchReg(USER);
-    if (!path.isEmpty())
-        return path;
-
-    path = pythonSearchReg(SYSTEM_32BIT);
-    if (!path.isEmpty())
-        return path;
-
-    path = pythonSearchReg(SYSTEM_64BIT);
-    if (!path.isEmpty())
-        return path;
-
-    // Fallback: Detect python from default locations
-    const QStringList dirs = QDir("C:/").entryList(QStringList("Python*"), QDir::Dirs, QDir::Name | QDir::Reversed);
-    foreach (const QString &dir, dirs) {
-        const QString path("C:/" + dir + '/');
-        if (QFile::exists(path + "python.exe"))
-            return path;
-    }
-
-    return QString();
-}
-
 bool Preferences::neverCheckFileAssoc() const
 {
     return value("Preferences/Win32/NeverCheckFileAssocation", false).toBool();
@@ -1104,7 +968,7 @@ void Preferences::setMagnetLinkAssoc(bool set)
 
     SHChangeNotify(SHCNE_ASSOCCHANGED, SHCNF_IDLIST, 0, 0);
 }
-#endif
+#endif // Q_OS_WIN
 
 #ifdef Q_OS_MAC
 namespace
@@ -1160,7 +1024,7 @@ void Preferences::setMagnetLinkAssoc()
     CFStringRef myBundleId = CFBundleGetIdentifier(CFBundleGetMainBundle());
     LSSetDefaultHandlerForURLScheme(magnetUrlScheme, myBundleId);
 }
-#endif
+#endif // Q_OS_MAC
 
 int Preferences::getTrackerPort() const
 {
@@ -1563,8 +1427,8 @@ void Preferences::setToolbarTextPosition(const int position)
 QList<QNetworkCookie> Preferences::getNetworkCookies() const
 {
     QList<QNetworkCookie> cookies;
-    QStringList rawCookies = value("Network/Cookies").toStringList();
-    foreach (const QString &rawCookie, rawCookies)
+    const QStringList rawCookies = value("Network/Cookies").toStringList();
+    for (const QString &rawCookie : rawCookies)
         cookies << QNetworkCookie::parseCookies(rawCookie.toUtf8());
 
     return cookies;
@@ -1573,12 +1437,22 @@ QList<QNetworkCookie> Preferences::getNetworkCookies() const
 void Preferences::setNetworkCookies(const QList<QNetworkCookie> &cookies)
 {
     QStringList rawCookies;
-    foreach (const QNetworkCookie &cookie, cookies)
+    for (const QNetworkCookie &cookie : cookies)
         rawCookies << cookie.toRawForm();
 
     setValue("Network/Cookies", rawCookies);
 }
 
+bool Preferences::isSpeedWidgetEnabled() const
+{
+    return value("SpeedWidget/Enabled", true).toBool();
+}
+
+void Preferences::setSpeedWidgetEnabled(bool enabled)
+{
+    setValue("SpeedWidget/Enabled", enabled);
+}
+
 int Preferences::getSpeedWidgetPeriod() const
 {
     return value("SpeedWidget/period", 1).toInt();
@@ -1604,10 +1478,10 @@ void Preferences::upgrade()
 {
     SettingsStorage *settingsStorage = SettingsStorage::instance();
 
-    QStringList labels = value("TransferListFilters/customLabels").toStringList();
+    const QStringList labels = value("TransferListFilters/customLabels").toStringList();
     if (!labels.isEmpty()) {
         QVariantMap categories = value("BitTorrent/Session/Categories").toMap();
-        foreach (const QString &label, labels) {
+        for (const QString &label : labels) {
             if (!categories.contains(label))
                 categories[label] = "";
         }
