@@ -126,7 +126,7 @@ namespace RSS
         bool smartFilter = false;
         QStringList previouslyMatchedEpisodes;
 
-        mutable QString lastComputedEpisode;
+        mutable QStringList lastComputedEpisodes;
         mutable QHash<QString, QRegularExpression> cachedRegexes;
 
         bool operator==(const AutoDownloadRuleData &other) const
@@ -237,7 +237,7 @@ bool AutoDownloadRule::matchesMustContainExpression(const QString &articleTitle)
 
     // Each expression is either a regex, or a set of wildcards separated by whitespace.
     // Accept if any complete expression matches.
-    for (const QString &expression : qAsConst(m_dataPtr->mustContain)) {
+    for (const QString &expression : asConst(m_dataPtr->mustContain)) {
         // A regex of the form "expr|" will always match, so do the same for wildcards
         if (matchesExpression(articleTitle, expression))
             return true;
@@ -246,14 +246,14 @@ bool AutoDownloadRule::matchesMustContainExpression(const QString &articleTitle)
     return false;
 }
 
-bool AutoDownloadRule::matchesMustNotContainExpression(const QString& articleTitle) const
+bool AutoDownloadRule::matchesMustNotContainExpression(const QString &articleTitle) const
 {
     if (m_dataPtr->mustNotContain.empty())
         return true;
 
     // Each expression is either a regex, or a set of wildcards separated by whitespace.
     // Reject if any complete expression matches.
-    for (const QString &expression : qAsConst(m_dataPtr->mustNotContain)) {
+    for (const QString &expression : asConst(m_dataPtr->mustNotContain)) {
         // A regex of the form "expr|" will always match, so do the same for wildcards
         if (matchesExpression(articleTitle, expression))
             return false;
@@ -262,10 +262,10 @@ bool AutoDownloadRule::matchesMustNotContainExpression(const QString& articleTit
     return true;
 }
 
-bool AutoDownloadRule::matchesEpisodeFilterExpression(const QString& articleTitle) const
+bool AutoDownloadRule::matchesEpisodeFilterExpression(const QString &articleTitle) const
 {
     // Reset the lastComputedEpisode, we don't want to leak it between matches
-    m_dataPtr->lastComputedEpisode.clear();
+    m_dataPtr->lastComputedEpisodes.clear();
 
     if (m_dataPtr->episodeFilter.isEmpty())
         return true;
@@ -332,7 +332,7 @@ bool AutoDownloadRule::matchesEpisodeFilterExpression(const QString& articleTitl
     return false;
 }
 
-bool AutoDownloadRule::matchesSmartEpisodeFilter(const QString& articleTitle) const
+bool AutoDownloadRule::matchesSmartEpisodeFilter(const QString &articleTitle) const
 {
     if (!useSmartFilter())
         return true;
@@ -343,11 +343,35 @@ bool AutoDownloadRule::matchesSmartEpisodeFilter(const QString& articleTitle) co
 
     // See if this episode has been downloaded before
     const bool previouslyMatched = m_dataPtr->previouslyMatchedEpisodes.contains(episodeStr);
-    const bool isRepack = articleTitle.contains("REPACK", Qt::CaseInsensitive) || articleTitle.contains("PROPER", Qt::CaseInsensitive);
-    if (previouslyMatched && !isRepack)
-        return false;
+    if (previouslyMatched) {
+        if (!AutoDownloader::instance()->downloadRepacks())
+            return false;
 
-    m_dataPtr->lastComputedEpisode = episodeStr;
+        // Now see if we've downloaded this particular repack/proper combination
+        const bool isRepack = articleTitle.contains("REPACK", Qt::CaseInsensitive);
+        const bool isProper = articleTitle.contains("PROPER", Qt::CaseInsensitive);
+
+        if (!isRepack && !isProper)
+            return false;
+
+        const QString fullEpisodeStr = QString("%1%2%3").arg(episodeStr,
+                                                             isRepack ? "-REPACK" : "",
+                                                             isProper ? "-PROPER" : "");
+        const bool previouslyMatchedFull = m_dataPtr->previouslyMatchedEpisodes.contains(fullEpisodeStr);
+        if (previouslyMatchedFull)
+            return false;
+
+        m_dataPtr->lastComputedEpisodes.append(fullEpisodeStr);
+
+        // If this is a REPACK and PROPER download, add the individual entries to the list
+        // so we don't download those
+        if (isRepack && isProper) {
+            m_dataPtr->lastComputedEpisodes.append(QString("%1-REPACK").arg(episodeStr));
+            m_dataPtr->lastComputedEpisodes.append(QString("%1-PROPER").arg(episodeStr));
+        }
+    }
+
+    m_dataPtr->lastComputedEpisodes.append(episodeStr);
     return true;
 }
 
@@ -379,10 +403,10 @@ bool AutoDownloadRule::accepts(const QVariantHash &articleData)
 
     setLastMatch(articleData[Article::KeyDate].toDateTime());
 
-    if (!m_dataPtr->lastComputedEpisode.isEmpty()) {
-        // TODO: probably need to add a marker for PROPER/REPACK to avoid duplicate downloads
-        m_dataPtr->previouslyMatchedEpisodes.append(m_dataPtr->lastComputedEpisode);
-        m_dataPtr->lastComputedEpisode.clear();
+    // If there's a matched episode string, add that to the previously matched list
+    if (!m_dataPtr->lastComputedEpisodes.isEmpty()) {
+        m_dataPtr->previouslyMatchedEpisodes.append(m_dataPtr->lastComputedEpisodes);
+        m_dataPtr->lastComputedEpisodes.clear();
     }
 
     return true;
@@ -442,7 +466,7 @@ AutoDownloadRule AutoDownloadRule::fromJsonObject(const QJsonObject &jsonObj, co
     QStringList feedURLs;
     if (feedsVal.isString())
         feedURLs << feedsVal.toString();
-    else foreach (const QJsonValue &urlVal, feedsVal.toArray())
+    else for (const QJsonValue &urlVal : asConst(feedsVal.toArray()))
         feedURLs << urlVal.toString();
     rule.setFeedURLs(feedURLs);
 
@@ -452,7 +476,7 @@ AutoDownloadRule AutoDownloadRule::fromJsonObject(const QJsonObject &jsonObj, co
         previouslyMatched << previouslyMatchedVal.toString();
     }
     else {
-        foreach (const QJsonValue &val, previouslyMatchedVal.toArray())
+        for (const QJsonValue &val : asConst(previouslyMatchedVal.toArray()))
             previouslyMatched << val.toString();
     }
     rule.setPreviouslyMatchedEpisodes(previouslyMatched);
