@@ -47,6 +47,7 @@
 #include "base/net/downloadmanager.h"
 #include "base/preferences.h"
 #include "base/profile.h"
+#include "base/utils/bytearray.h"
 #include "base/utils/foreignapps.h"
 #include "base/utils/fs.h"
 #include "base/utils/misc.h"
@@ -64,7 +65,7 @@ namespace
         while (iter.hasNext())
             dirs += iter.next();
 
-        for (const QString &dir : qAsConst(dirs)) {
+        for (const QString &dir : asConst(dirs)) {
             // python 3: remove "__pycache__" folders
             if (dir.endsWith("/__pycache__")) {
                 Utils::Fs::removeDirRecursive(dir);
@@ -100,9 +101,17 @@ SearchPluginManager::~SearchPluginManager()
 
 SearchPluginManager *SearchPluginManager::instance()
 {
+    if (!m_instance)
+        m_instance = new SearchPluginManager;
     return m_instance;
 }
 
+void SearchPluginManager::freeInstance()
+{
+    if (m_instance)
+        delete m_instance;
+}
+
 QStringList SearchPluginManager::allPlugins() const
 {
     return m_plugins.keys();
@@ -111,7 +120,7 @@ QStringList SearchPluginManager::allPlugins() const
 QStringList SearchPluginManager::enabledPlugins() const
 {
     QStringList plugins;
-    for (const PluginInfo *plugin : qAsConst(m_plugins)) {
+    for (const PluginInfo *plugin : asConst(m_plugins)) {
         if (plugin->enabled)
             plugins << plugin->name;
     }
@@ -122,9 +131,9 @@ QStringList SearchPluginManager::enabledPlugins() const
 QStringList SearchPluginManager::supportedCategories() const
 {
     QStringList result;
-    for (const PluginInfo *plugin : qAsConst(m_plugins)) {
+    for (const PluginInfo *plugin : asConst(m_plugins)) {
         if (plugin->enabled) {
-            foreach (QString cat, plugin->supportedCategories) {
+            for (const QString &cat : plugin->supportedCategories) {
                 if (!result.contains(cat))
                     result << cat;
             }
@@ -145,8 +154,8 @@ QStringList SearchPluginManager::getPluginCategories(const QString &pluginName)
         plugins << pluginName.trimmed();
 
     QSet<QString> categories;
-    for (const QString &pluginName : qAsConst(plugins)) {
-        const PluginInfo *plugin = pluginInfo(pluginName);
+    for (const QString &name : asConst(plugins)) {
+        const PluginInfo *plugin = pluginInfo(name);
         if (!plugin) continue; // plugin wasn't found
         for (const QString &category : plugin->supportedCategories)
             categories << category;
@@ -187,8 +196,6 @@ void SearchPluginManager::updatePlugin(const QString &name)
 // Install or update plugin from file or url
 void SearchPluginManager::installPlugin(const QString &source)
 {
-    qDebug("Asked to install plugin at %s", qUtf8Printable(source));
-
     clearPythonCache(engineLocation());
 
     if (Utils::Misc::isUrl(source)) {
@@ -215,12 +222,10 @@ void SearchPluginManager::installPlugin(const QString &source)
 
 void SearchPluginManager::installPlugin_impl(const QString &name, const QString &path)
 {
-    PluginVersion newVersion = getPluginVersion(path);
-    qDebug() << "Version to be installed:" << newVersion;
-
+    const PluginVersion newVersion = getPluginVersion(path);
     PluginInfo *plugin = pluginInfo(name);
     if (plugin && !(plugin->version < newVersion)) {
-        qDebug("Apparently update is not needed, we have a more recent version");
+        LogMsg(tr("Plugin already at version %1, which is greater than %2").arg(plugin->version, newVersion), Log::INFO);
         emit pluginUpdateFailed(name, tr("A more recent version of this plugin is already installed."));
         return;
     }
@@ -242,6 +247,7 @@ void SearchPluginManager::installPlugin_impl(const QString &name, const QString
     if (!m_plugins.contains(name)) {
         // Remove broken file
         Utils::Fs::forceRemove(destPath);
+        LogMsg(tr("Plugin %1 is not supported.").arg(name), Log::INFO);
         if (updated) {
             // restore backup
             QFile::copy(destPath + ".bak", destPath);
@@ -256,8 +262,10 @@ void SearchPluginManager::installPlugin_impl(const QString &name, const QString
     }
     else {
         // Install was successful, remove backup
-        if (updated)
+        if (updated) {
+            LogMsg(tr("Plugin %1 has been successfully updated.").arg(name), Log::INFO);
             Utils::Fs::forceRemove(destPath + ".bak");
+        }
     }
 }
 
@@ -269,9 +277,8 @@ bool SearchPluginManager::uninstallPlugin(const QString &name)
     QDir pluginsFolder(pluginsLocation());
     QStringList filters;
     filters << name + ".*";
-    QStringList files = pluginsFolder.entryList(filters, QDir::Files, QDir::Unsorted);
-    QString file;
-    foreach (file, files)
+    const QStringList files = pluginsFolder.entryList(filters, QDir::Files, QDir::Unsorted);
+    for (const QString &file : files)
         Utils::Fs::forceRemove(pluginsFolder.absoluteFilePath(file));
     // Remove it from supported engines
     delete m_plugins.take(name);
@@ -494,37 +501,37 @@ void SearchPluginManager::update()
 
 void SearchPluginManager::parseVersionInfo(const QByteArray &info)
 {
-    qDebug("Checking if update is needed");
-
     QHash<QString, PluginVersion> updateInfo;
-    bool dataCorrect = false;
-    QList<QByteArray> lines = info.split('\n');
-    foreach (QByteArray line, lines) {
+    int numCorrectData = 0;
+
+    const QList<QByteArray> lines = Utils::ByteArray::splitToViews(info, "\n", QString::SkipEmptyParts);
+    for (QByteArray line : lines) {
         line = line.trimmed();
         if (line.isEmpty()) continue;
         if (line.startsWith('#')) continue;
 
-        QList<QByteArray> list = line.split(' ');
+        const QList<QByteArray> list = Utils::ByteArray::splitToViews(line, ":", QString::SkipEmptyParts);
         if (list.size() != 2) continue;
 
-        QString pluginName = QString(list.first());
-        if (!pluginName.endsWith(':')) continue;
+        const QString pluginName = list.first().trimmed();
+        const PluginVersion version = PluginVersion::tryParse(list.last().trimmed(), {});
 
-        pluginName.chop(1); // remove trailing ':'
-        PluginVersion version = PluginVersion::tryParse(list.last(), {});
-        if (version == PluginVersion()) continue;
+        if (!version.isValid()) continue;
 
-        dataCorrect = true;
+        ++numCorrectData;
         if (isUpdateNeeded(pluginName, version)) {
-            qDebug("Plugin: %s is outdated", qUtf8Printable(pluginName));
+            LogMsg(tr("Plugin \"%1\" is outdated, updating to version %2").arg(pluginName, version), Log::INFO);
             updateInfo[pluginName] = version;
         }
     }
 
-    if (!dataCorrect)
-        emit checkForUpdatesFailed(tr("An incorrect update info received."));
-    else
+    if (numCorrectData < lines.size()) {
+        emit checkForUpdatesFailed(tr("Incorrect update info received for %1 out of %2 plugins.")
+            .arg(QString::number(lines.size() - numCorrectData), QString::number(lines.size())));
+    }
+    else {
         emit checkForUpdatesFinished(updateInfo);
+    }
 }
 
 bool SearchPluginManager::isUpdateNeeded(QString pluginName, PluginVersion newVersion) const
@@ -533,7 +540,6 @@ bool SearchPluginManager::isUpdateNeeded(QString pluginName, PluginVersion newVe
     if (!plugin) return true;
 
     PluginVersion oldVersion = plugin->version;
-    qDebug() << "IsUpdate needed? to be installed:" << newVersion << ", already installed:" << oldVersion;
     return (newVersion > oldVersion);
 }
 
