@@ -79,11 +79,10 @@ namespace Utils
         QString boostVersionString();
         QString libtorrentVersionString();
 
-        QString unitString(SizeUnit unit);
+        QString unitString(SizeUnit unit, bool isSpeed = false);
 
         // return the best user friendly storage unit (B, KiB, MiB, GiB, TiB)
         // value must be given in bytes
-        bool friendlyUnit(qint64 sizeInBytes, qreal &val, SizeUnit &unit);
         QString friendlyUnit(qint64 bytesValue, bool isSpeed = false);
         int friendlyUnitPrecision(SizeUnit unit);
         qint64 sizeInBytes(qreal size, SizeUnit unit);
@@ -125,7 +124,7 @@ namespace Utils
             return reinterpret_cast<T>(
                 ::GetProcAddress(::LoadLibraryW(pathWchar.get()), funcName));
         }
-#endif
+#endif // Q_OS_WIN
     }
 }
 
