@@ -30,8 +30,10 @@
 
 #include <QDebug>
 #include <QFile>
+#include <QDir>
 #include <QMenu>
 #include <QPushButton>
+#include <QShortcut>
 #include <QString>
 #include <QUrl>
 #include <QVector>
@@ -40,14 +42,12 @@
 #include "base/bittorrent/magneturi.h"
 #include "base/bittorrent/session.h"
 #include "base/bittorrent/torrenthandle.h"
-#include "base/bittorrent/torrentinfo.h"
 #include "base/global.h"
 #include "base/net/downloadhandler.h"
 #include "base/net/downloadmanager.h"
 #include "base/preferences.h"
 #include "base/settingsstorage.h"
 #include "base/torrentfileguard.h"
-#include "base/unicodestrings.h"
 #include "base/utils/fs.h"
 #include "base/utils/misc.h"
 #include "base/utils/string.h"
@@ -62,16 +62,14 @@
 
 namespace
 {
-#define SETTINGS_KEY(name) QStringLiteral("AddNewTorrentDialog/" name)
-    const QString KEY_ENABLED = SETTINGS_KEY("Enabled");
-    const QString KEY_DEFAULTCATEGORY = SETTINGS_KEY("DefaultCategory");
-    const QString KEY_TREEHEADERSTATE = SETTINGS_KEY("TreeHeaderState");
-    const QString KEY_WIDTH = SETTINGS_KEY("Width");
-    const QString KEY_EXPANDED = SETTINGS_KEY("Expanded");
-    const QString KEY_TOPLEVEL = SETTINGS_KEY("TopLevel");
-    const QString KEY_SAVEPATHHISTORY = SETTINGS_KEY("SavePathHistory");
-    const QString KEY_SAVEPATHHISTORYLENGTH = SETTINGS_KEY("SavePathHistoryLength");
-    const QString KEY_REMEMBERLASTSAVEPATH = SETTINGS_KEY("RememberLastSavePath");
+#define SETTINGS_KEY(name) "AddNewTorrentDialog/" name
+    const QString KEY_ENABLED = QStringLiteral(SETTINGS_KEY("Enabled"));
+    const QString KEY_DEFAULTCATEGORY = QStringLiteral(SETTINGS_KEY("DefaultCategory"));
+    const QString KEY_TREEHEADERSTATE = QStringLiteral(SETTINGS_KEY("TreeHeaderState"));
+    const QString KEY_TOPLEVEL = QStringLiteral(SETTINGS_KEY("TopLevel"));
+    const QString KEY_SAVEPATHHISTORY = QStringLiteral(SETTINGS_KEY("SavePathHistory"));
+    const QString KEY_SAVEPATHHISTORYLENGTH = QStringLiteral(SETTINGS_KEY("SavePathHistoryLength"));
+    const QString KEY_REMEMBERLASTSAVEPATH = QStringLiteral(SETTINGS_KEY("RememberLastSavePath"));
 
     // just a shortcut
     inline SettingsStorage *settings()
@@ -91,10 +89,13 @@ AddNewTorrentDialog::AddNewTorrentDialog(const BitTorrent::AddTorrentParams &inP
     , m_hasMetadata(false)
     , m_oldIndex(0)
     , m_torrentParams(inParams)
+    , m_storeDialogSize(SETTINGS_KEY("DialogSize"))
+    , m_storeSplitterState(SETTINGS_KEY("SplitterState"))
 {
     // TODO: set dialog file properties using m_torrentParams.filePriorities
     m_ui->setupUi(this);
     setAttribute(Qt::WA_DeleteOnClose);
+
     m_ui->lblMetaLoading->setVisible(false);
     m_ui->progMetaLoading->setVisible(false);
 
@@ -151,11 +152,12 @@ AddNewTorrentDialog::AddNewTorrentDialog(const BitTorrent::AddTorrentParams &inP
     m_ui->contentTreeView->header()->setSortIndicator(0, Qt::AscendingOrder);
     loadState();
     // Signal / slots
-    connect(m_ui->toolButtonAdvanced, &QToolButton::clicked, this, &AddNewTorrentDialog::showAdvancedSettings);
     connect(m_ui->doNotDeleteTorrentCheckBox, &QCheckBox::clicked, this, &AddNewTorrentDialog::doNotDeleteTorrentClicked);
     QShortcut *editHotkey = new QShortcut(Qt::Key_F2, m_ui->contentTreeView, nullptr, nullptr, Qt::WidgetShortcut);
-    connect(editHotkey, &QShortcut::activated, this, &AddNewTorrentDialog::renameSelectedFile);
-    connect(m_ui->contentTreeView, &QAbstractItemView::doubleClicked, this, &AddNewTorrentDialog::renameSelectedFile);
+    connect(editHotkey, &QShortcut::activated
+            , this, [this]() { m_ui->contentTreeView->renameSelectedFile(m_torrentInfo); });
+    connect(m_ui->contentTreeView, &QAbstractItemView::doubleClicked
+            , this, [this]() { m_ui->contentTreeView->renameSelectedFile(m_torrentInfo); });
 
     m_ui->buttonBox->button(QDialogButtonBox::Ok)->setFocus();
 }
@@ -209,22 +211,17 @@ void AddNewTorrentDialog::setSavePathHistoryLength(int value)
 
 void AddNewTorrentDialog::loadState()
 {
+    Utils::Gui::resize(this, m_storeDialogSize);
+    m_ui->splitter->restoreState(m_storeSplitterState);
     m_headerState = settings()->loadValue(KEY_TREEHEADERSTATE).toByteArray();
-
-    const QSize newSize = Utils::Gui::scaledSize(this, size());
-    const int width = settings()->loadValue(KEY_WIDTH, newSize.width()).toInt();
-    const int height = newSize.height();
-    resize(width, height);
-
-    m_ui->toolButtonAdvanced->setChecked(settings()->loadValue(KEY_EXPANDED).toBool());
 }
 
 void AddNewTorrentDialog::saveState()
 {
+    m_storeDialogSize = size();
+    m_storeSplitterState = m_ui->splitter->saveState();
     if (m_contentModel)
         settings()->storeValue(KEY_TREEHEADERSTATE, m_ui->contentTreeView->header()->saveState());
-    settings()->storeValue(KEY_WIDTH, width());
-    settings()->storeValue(KEY_EXPANDED, m_ui->toolButtonAdvanced->isChecked());
 }
 
 void AddNewTorrentDialog::show(QString source, const BitTorrent::AddTorrentParams &inParams, QWidget *parent)
@@ -250,11 +247,7 @@ void AddNewTorrentDialog::show(QString source, const BitTorrent::AddTorrentParam
             ok = dlg->loadTorrent(source);
 
         if (ok)
-#ifdef Q_OS_MAC
-            dlg->exec();
-#else
-            dlg->open();
-#endif
+            dlg->QDialog::show();
         else
             delete dlg;
     }
@@ -314,7 +307,7 @@ bool AddNewTorrentDialog::loadTorrent(const QString &torrentPath)
         return false;
     }
 
-    m_ui->lblhash->setText(m_hash);
+    m_ui->labelHashData->setText(m_hash);
     setupTreeview();
     TMMChanged(m_ui->comboTTM->currentIndex());
     return true;
@@ -359,7 +352,7 @@ bool AddNewTorrentDialog::loadMagnet(const BitTorrent::MagnetUri &magnetUri)
 
     BitTorrent::Session::instance()->loadMetadata(magnetUri);
     setMetadataProgressIndicator(true, tr("Retrieving metadata..."));
-    m_ui->lblhash->setText(m_hash);
+    m_ui->labelHashData->setText(m_hash);
 
     return true;
 }
@@ -373,27 +366,6 @@ void AddNewTorrentDialog::showEvent(QShowEvent *event)
     raise();
 }
 
-void AddNewTorrentDialog::showAdvancedSettings(bool show)
-{
-    const int minimumW = minimumWidth();
-    setMinimumWidth(width()); // to remain the same width
-    if (show) {
-        m_ui->toolButtonAdvanced->setText(QString::fromUtf8(C_UP));
-        m_ui->groupBoxSettings->setVisible(true);
-        m_ui->infoGroup->setVisible(true);
-        m_ui->contentTreeView->setVisible(m_hasMetadata);
-        static_cast<QVBoxLayout *>(layout())->insertWidget(layout()->indexOf(m_ui->checkBoxNeverShow) + 1, m_ui->toolButtonAdvanced);
-    }
-    else {
-        m_ui->toolButtonAdvanced->setText(QString::fromUtf8(C_DOWN));
-        m_ui->groupBoxSettings->setVisible(false);
-        m_ui->infoGroup->setVisible(false);
-        m_ui->buttonsHLayout->insertWidget(0, layout()->takeAt(layout()->indexOf(m_ui->checkBoxNeverShow) + 1)->widget());
-    }
-    adjustSize();
-    setMinimumWidth(minimumW);
-}
-
 void AddNewTorrentDialog::saveSavePathHistory() const
 {
     // Get current history
@@ -447,7 +419,7 @@ void AddNewTorrentDialog::updateDiskSpaceLabel()
     sizeString += tr("Free space on disk: %1").arg(Utils::Misc::friendlyUnit(Utils::Fs::freeDiskSpaceOnPath(
                                                                    m_ui->savePath->selectedPath())));
     sizeString += ')';
-    m_ui->labelSize->setText(sizeString);
+    m_ui->labelSizeData->setText(sizeString);
 }
 
 void AddNewTorrentDialog::onSavePathChanged(const QString &newPath)
@@ -480,107 +452,6 @@ void AddNewTorrentDialog::setSavePath(const QString &newPath)
     onSavePathChanged(newPath);
 }
 
-void AddNewTorrentDialog::renameSelectedFile()
-{
-    const QModelIndexList selectedIndexes = m_ui->contentTreeView->selectionModel()->selectedRows(0);
-    if (selectedIndexes.size() != 1) return;
-
-    const QModelIndex modelIndex = selectedIndexes.first();
-    if (!modelIndex.isValid()) return;
-
-    // Ask for new name
-    bool ok = false;
-    const bool isFile = (m_contentModel->itemType(modelIndex) == TorrentContentModelItem::FileType);
-    QString newName = AutoExpandableDialog::getText(this, tr("Renaming"), tr("New name:"), QLineEdit::Normal
-            , modelIndex.data().toString(), &ok, isFile).trimmed();
-    if (!ok) return;
-
-    if (newName.isEmpty() || !Utils::Fs::isValidFileSystemName(newName)) {
-        RaisedMessageBox::warning(this, tr("Rename error"),
-                                  tr("The name is empty or contains forbidden characters, please choose a different one."),
-                                  QMessageBox::Ok);
-        return;
-    }
-
-    if (isFile) {
-        const int fileIndex = m_contentModel->getFileIndex(modelIndex);
-
-        if (newName.endsWith(QB_EXT))
-            newName.chop(QB_EXT.size());
-        const QString oldFileName = m_torrentInfo.fileName(fileIndex);
-        const QString oldFilePath = m_torrentInfo.filePath(fileIndex);
-        const QString newFilePath = oldFilePath.leftRef(oldFilePath.size() - oldFileName.size()) + newName;
-
-        if (oldFileName == newName) {
-            qDebug("Name did not change: %s", qUtf8Printable(oldFileName));
-            return;
-        }
-
-        // check if that name is already used
-        for (int i = 0; i < m_torrentInfo.filesCount(); ++i) {
-            if (i == fileIndex) continue;
-            if (Utils::Fs::sameFileNames(m_torrentInfo.filePath(i), newFilePath)) {
-                RaisedMessageBox::warning(this, tr("Rename error"),
-                                          tr("This name is already in use in this folder. Please use a different name."),
-                                          QMessageBox::Ok);
-                return;
-            }
-        }
-
-        qDebug("Renaming %s to %s", qUtf8Printable(oldFilePath), qUtf8Printable(newFilePath));
-        m_torrentInfo.renameFile(fileIndex, newFilePath);
-
-        m_contentModel->setData(modelIndex, newName);
-    }
-    else {
-        // renaming a folder
-        QStringList pathItems;
-        pathItems << modelIndex.data().toString();
-        QModelIndex parent = m_contentModel->parent(modelIndex);
-        while (parent.isValid()) {
-            pathItems.prepend(parent.data().toString());
-            parent = m_contentModel->parent(parent);
-        }
-        const QString oldPath = pathItems.join('/');
-        pathItems.removeLast();
-        pathItems << newName;
-        QString newPath = pathItems.join('/');
-        if (Utils::Fs::sameFileNames(oldPath, newPath)) {
-            qDebug("Name did not change");
-            return;
-        }
-        if (!newPath.endsWith('/')) newPath += '/';
-        // Check for overwriting
-        for (int i = 0; i < m_torrentInfo.filesCount(); ++i) {
-            const QString currentName = m_torrentInfo.filePath(i);
-#if defined(Q_OS_UNIX) || defined(Q_WS_QWS)
-            if (currentName.startsWith(newPath, Qt::CaseSensitive)) {
-#else
-            if (currentName.startsWith(newPath, Qt::CaseInsensitive)) {
-#endif
-                RaisedMessageBox::warning(this, tr("The folder could not be renamed"),
-                                          tr("This name is already in use in this folder. Please use a different name."),
-                                          QMessageBox::Ok);
-                return;
-            }
-        }
-        // Replace path in all files
-        for (int i = 0; i < m_torrentInfo.filesCount(); ++i) {
-            const QString currentName = m_torrentInfo.filePath(i);
-            if (currentName.startsWith(oldPath)) {
-                QString newName = currentName;
-                newName.replace(0, oldPath.length(), newPath);
-                newName = Utils::Fs::expandPath(newName);
-                qDebug("Rename %s to %s", qUtf8Printable(currentName), qUtf8Printable(newName));
-                m_torrentInfo.renameFile(i, newName);
-            }
-        }
-
-        // Rename folder in torrent files model too
-        m_contentModel->setData(modelIndex, newName);
-    }
-}
-
 void AddNewTorrentDialog::populateSavePathComboBox()
 {
     m_ui->savePath->clear();
@@ -620,7 +491,7 @@ void AddNewTorrentDialog::displayContentTreeMenu(const QPoint &)
     QAction *act = myFilesLlistMenu.exec(QCursor::pos());
     if (act) {
         if (act == actRename) {
-            renameSelectedFile();
+            m_ui->contentTreeView->renameSelectedFile(m_torrentInfo);
         }
         else {
             BitTorrent::FilePriority prio = BitTorrent::FilePriority::Normal;
@@ -642,9 +513,6 @@ void AddNewTorrentDialog::displayContentTreeMenu(const QPoint &)
 
 void AddNewTorrentDialog::accept()
 {
-    if (!m_hasMetadata)
-        disconnect(this, SLOT(updateMetadata(const BitTorrent::TorrentInfo&)));
-
     // TODO: Check if destination actually exists
     m_torrentParams.skipChecking = m_ui->skipCheckingCheckBox->isChecked();
 
@@ -690,7 +558,6 @@ void AddNewTorrentDialog::accept()
 void AddNewTorrentDialog::reject()
 {
     if (!m_hasMetadata) {
-        disconnect(this, SLOT(updateMetadata(BitTorrent::TorrentInfo)));
         setMetadataProgressIndicator(false);
         BitTorrent::Session::instance()->cancelLoadMetadata(m_hash);
     }
@@ -702,7 +569,8 @@ void AddNewTorrentDialog::updateMetadata(const BitTorrent::TorrentInfo &info)
 {
     if (info.hash() != m_hash) return;
 
-    disconnect(this, SLOT(updateMetadata(BitTorrent::TorrentInfo)));
+    disconnect(BitTorrent::Session::instance(), &BitTorrent::Session::metadataLoaded, this, &AddNewTorrentDialog::updateMetadata);
+
     if (!info.isValid()) {
         RaisedMessageBox::critical(this, tr("I/O Error"), ("Invalid metadata."));
         setMetadataProgressIndicator(false, tr("Invalid metadata"));
@@ -730,16 +598,16 @@ void AddNewTorrentDialog::setMetadataProgressIndicator(bool visibleIndicator, co
 void AddNewTorrentDialog::setupTreeview()
 {
     if (!m_hasMetadata) {
-        setCommentText(tr("Not Available", "This comment is unavailable"));
-        m_ui->labelDate->setText(tr("Not Available", "This date is unavailable"));
+        m_ui->labelCommentData->setText(tr("Not Available", "This comment is unavailable"));
+        m_ui->labelDateData->setText(tr("Not Available", "This date is unavailable"));
     }
     else {
         // Set dialog title
         setWindowTitle(m_torrentInfo.name());
 
         // Set torrent information
-        setCommentText(Utils::Misc::parseHtmlLinks(m_torrentInfo.comment()));
-        m_ui->labelDate->setText(!m_torrentInfo.creationDate().isNull() ? m_torrentInfo.creationDate().toString(Qt::DefaultLocaleShortDate) : tr("Not available"));
+        m_ui->labelCommentData->setText(Utils::Misc::parseHtmlLinks(m_torrentInfo.comment()));
+        m_ui->labelDateData->setText(!m_torrentInfo.creationDate().isNull() ? m_torrentInfo.creationDate().toString(Qt::DefaultLocaleShortDate) : tr("Not available"));
 
         // Prepare content tree
         m_contentModel = new TorrentContentFilterModel(this);
@@ -766,7 +634,6 @@ void AddNewTorrentDialog::setupTreeview()
     }
 
     updateDiskSpaceLabel();
-    showAdvancedSettings(settings()->loadValue(KEY_EXPANDED, false).toBool());
 }
 
 void AddNewTorrentDialog::handleDownloadFailed(const QString &url, const QString &reason)
@@ -801,7 +668,6 @@ void AddNewTorrentDialog::TMMChanged(int index)
         m_ui->groupBoxSavePath->setEnabled(true);
         m_ui->savePath->blockSignals(false);
         m_ui->savePath->setCurrentIndex(m_oldIndex < m_ui->savePath->count() ? m_oldIndex : m_ui->savePath->count() - 1);
-        m_ui->toolButtonAdvanced->setEnabled(true);
     }
     else {
         m_ui->groupBoxSavePath->setEnabled(false);
@@ -809,23 +675,9 @@ void AddNewTorrentDialog::TMMChanged(int index)
         m_ui->savePath->clear();
         QString savePath = BitTorrent::Session::instance()->categorySavePath(m_ui->categoryComboBox->currentText());
         m_ui->savePath->addItem(savePath);
-        m_ui->toolButtonAdvanced->setChecked(true);
-        m_ui->toolButtonAdvanced->setEnabled(false);
-        showAdvancedSettings(true);
     }
 }
 
-void AddNewTorrentDialog::setCommentText(const QString &str) const
-{
-    m_ui->commentLabel->setText(str);
-
-    // workaround for the additional space introduced by QScrollArea
-    int lineHeight = m_ui->commentLabel->fontMetrics().lineSpacing();
-    int lines = 1 + str.count('\n');
-    int height = lineHeight * lines;
-    m_ui->scrollArea->setMaximumHeight(height);
-}
-
 void AddNewTorrentDialog::doNotDeleteTorrentClicked(bool checked)
 {
     m_torrentGuard->setAutoRemove(!checked);
