@@ -31,11 +31,11 @@
 
 #include <QDialog>
 #include <QScopedPointer>
-#include <QShortcut>
 
 #include "base/bittorrent/addtorrentparams.h"
 #include "base/bittorrent/infohash.h"
 #include "base/bittorrent/torrentinfo.h"
+#include "base/settingvalue.h"
 
 namespace BitTorrent
 {
@@ -72,11 +72,9 @@ public:
     static void show(QString source, QWidget *parent);
 
 private slots:
-    void showAdvancedSettings(bool show);
     void displayContentTreeMenu(const QPoint &);
     void updateDiskSpaceLabel();
     void onSavePathChanged(const QString &newPath);
-    void renameSelectedFile();
     void updateMetadata(const BitTorrent::TorrentInfo &info);
     void handleDownloadFailed(const QString &url, const QString &reason);
     void handleRedirectedToMagnet(const QString &url, const QString &magnetUri);
@@ -99,7 +97,6 @@ private:
     void saveState();
     void setMetadataProgressIndicator(bool visibleIndicator, const QString &labelText = QString());
     void setupTreeview();
-    void setCommentText(const QString &str) const;
     void setSavePath(const QString &newPath);
 
     void showEvent(QShowEvent *event) override;
@@ -115,6 +112,9 @@ private:
     int m_oldIndex;
     QScopedPointer<TorrentFileGuard> m_torrentGuard;
     BitTorrent::AddTorrentParams m_torrentParams;
+
+    CachedSettingValue<QSize> m_storeDialogSize;
+    CachedSettingValue<QByteArray> m_storeSplitterState;
 };
 
 #endif // ADDNEWTORRENTDIALOG_H
