@@ -304,7 +304,7 @@ OptionsDialog::OptionsDialog(QWidget *parent)
         .arg(tr("Supported parameters (case sensitive):")
             , tr("%N: Torrent name")
             , tr("%L: Category")
-            , tr("%G: Tags (seperated by comma)")
+            , tr("%G: Tags (separated by comma)")
             , tr("%F: Content path (same as root path for multifile torrent)")
             , tr("%R: Root path (first torrent subdirectory path)")
             , tr("%D: Save path")
