@@ -36,7 +36,7 @@
 #include <QStyleOptionProgressBar>
 #include <QStyleOptionViewItem>
 
-#ifdef Q_OS_WIN
+#if defined(Q_OS_WIN) || defined(Q_OS_MACOS)
 #include <QProxyStyle>
 #endif
 
@@ -76,7 +76,7 @@ public:
                 newopt.minimum = 0;
                 newopt.state |= QStyle::State_Enabled;
                 newopt.textVisible = true;
-#ifndef Q_OS_WIN
+#if !defined(Q_OS_WIN) && !defined(Q_OS_MACOS)
                 QApplication::style()->drawControl(QStyle::CE_ProgressBar, &newopt, painter);
 #else
                 // XXX: To avoid having the progress text on the right of the bar
