@@ -41,7 +41,7 @@
 
 namespace
 {
-    const QString RSS_URL {QStringLiteral("https://www.fosshub.com/software/feedqBittorent")};
+    const QString RSS_URL {QStringLiteral("https://www.fosshub.com/feed/5b8793a7f9ee5a5c3e97a3b2.xml")};
 
     QString getStringValue(QXmlStreamReader &xml);
 }
@@ -141,7 +141,7 @@ bool ProgramUpdater::isVersionMoreRecent(const QString &remoteVersion) const
         qDebug() << Q_FUNC_INFO << "local version:" << localVersion << "/" << QBT_VERSION;
         QStringList remoteParts = remoteVersion.split('.');
         QStringList localParts = localVersion.split('.');
-        for (int i = 0; i<qMin(remoteParts.size(), localParts.size()); ++i) {
+        for (int i = 0; i < qMin(remoteParts.size(), localParts.size()); ++i) {
             if (remoteParts[i].toInt() > localParts[i].toInt())
                 return true;
             if (remoteParts[i].toInt() < localParts[i].toInt())
