@@ -49,6 +49,7 @@
 #include <QTreeView>
 
 #include "base/bittorrent/session.h"
+#include "base/global.h"
 #include "base/preferences.h"
 #include "base/search/searchpluginmanager.h"
 #include "base/search/searchhandler.h"
@@ -133,8 +134,7 @@ SearchWidget::SearchWidget(MainWindow *mainWindow)
     connect(m_tabStatusChangedMapper, static_cast<void (QSignalMapper::*)(QWidget *)>(&QSignalMapper::mapped)
             , this, &SearchWidget::tabStatusChanged);
 
-    // NOTE: Although SearchManager is Application-wide component now, we still create it the legacy way.
-    auto *searchManager = new SearchPluginManager;
+    auto *searchManager = SearchPluginManager::instance();
     const auto onPluginChanged = [this]()
     {
         fillPluginComboBox();
@@ -167,11 +167,11 @@ void SearchWidget::fillCatCombobox()
 
     using QStrPair = QPair<QString, QString>;
     QList<QStrPair> tmpList;
-    foreach (const QString &cat, SearchPluginManager::instance()->getPluginCategories(selectedPlugin()))
+    for (const QString &cat : asConst(SearchPluginManager::instance()->getPluginCategories(selectedPlugin())))
         tmpList << qMakePair(SearchPluginManager::categoryFullName(cat), cat);
     std::sort(tmpList.begin(), tmpList.end(), [](const QStrPair &l, const QStrPair &r) { return (QString::localeAwareCompare(l.first, r.first) < 0); });
 
-    foreach (const QStrPair &p, tmpList) {
+    for (const QStrPair &p : asConst(tmpList)) {
         qDebug("Supported category: %s", qUtf8Printable(p.second));
         m_ui->comboCategory->addItem(p.first, QVariant(p.second));
     }
@@ -189,11 +189,11 @@ void SearchWidget::fillPluginComboBox()
 
     using QStrPair = QPair<QString, QString>;
     QList<QStrPair> tmpList;
-    foreach (const QString &name, SearchPluginManager::instance()->enabledPlugins())
+    for (const QString &name : asConst(SearchPluginManager::instance()->enabledPlugins()))
         tmpList << qMakePair(SearchPluginManager::instance()->pluginFullName(name), name);
     std::sort(tmpList.begin(), tmpList.end(), [](const QStrPair &l, const QStrPair &r) { return (l.first < r.first); } );
 
-    foreach (const QStrPair &p, tmpList)
+    for (const QStrPair &p : asConst(tmpList))
         m_ui->selectPlugin->addItem(p.first, QVariant(p.second));
 
     if (m_ui->selectPlugin->count() > 3)
@@ -231,7 +231,6 @@ void SearchWidget::selectActivePage()
 SearchWidget::~SearchWidget()
 {
     qDebug("Search destruction");
-    delete SearchPluginManager::instance();
     delete m_ui;
 }
 
@@ -296,7 +295,7 @@ void SearchWidget::giveFocusToSearchInput()
 // Function called when we click on search button
 void SearchWidget::on_searchButton_clicked()
 {
-    if (Utils::ForeignApps::pythonInfo().version.majorNumber() <= 0) {
+    if (!Utils::ForeignApps::pythonInfo().isValid()) {
         m_mainWindow->showNotificationBaloon(tr("Search Engine"), tr("Please install Python to use the Search Engine."));
         return;
     }
