@@ -29,6 +29,7 @@
 #ifndef TORRENTCONTENTMODELFOLDER_H
 #define TORRENTCONTENTMODELFOLDER_H
 
+#include "base/bittorrent/filepriority.h"
 #include "torrentcontentmodelitem.h"
 
 class TorrentContentModelFolder : public TorrentContentModelItem
@@ -49,7 +50,7 @@ public:
     void recalculateAvailability();
     void updatePriority();
 
-    void setPriority(int newPriority, bool updateParent = true) override;
+    void setPriority(BitTorrent::FilePriority newPriority, bool updateParent = true) override;
 
     void deleteAllChildren();
     const QList<TorrentContentModelItem*> &children() const;
