@@ -55,9 +55,12 @@ private slots:
     void createCategoryAction();
     void editCategoryAction();
     void removeCategoriesAction();
+    void categoriesAction();
     void addAction();
     void deleteAction();
     void addTrackersAction();
+    void editTrackerAction();
+    void removeTrackersAction();
     void filePrioAction();
     void uploadLimitAction();
     void downloadLimitAction();
