@@ -34,6 +34,7 @@
 #include <QObject>
 #include <QRegularExpression>
 #include <QSet>
+#include <QTranslator>
 
 #include "api/isessionmanager.h"
 #include "base/http/irequesthandler.h"
@@ -42,9 +43,9 @@
 #include "base/utils/net.h"
 #include "base/utils/version.h"
 
-constexpr Utils::Version<int, 3, 2> API_VERSION {2, 1, 0};
-constexpr int COMPAT_API_VERSION = 21;
-constexpr int COMPAT_API_VERSION_MIN = 21;
+constexpr Utils::Version<int, 3, 2> API_VERSION {2, 2, 0};
+constexpr int COMPAT_API_VERSION = 23;
+constexpr int COMPAT_API_VERSION_MIN = 23;
 
 class APIController;
 class WebApplication;
@@ -109,6 +110,8 @@ private:
     void sendFile(const QString &path);
     void sendWebUIFile();
 
+    void translateDocument(QString &data);
+
     // Session management
     QString generateSid() const;
     void sessionInitialize();
@@ -142,6 +145,8 @@ private:
     };
     QMap<QString, TranslatedFile> m_translatedFiles;
     QString m_currentLocale;
+    QTranslator m_translator;
+    bool m_translationFileLoaded = false;
 
     bool m_isLocalAuthEnabled;
     bool m_isAuthSubnetWhitelistEnabled;
@@ -151,5 +156,7 @@ private:
     QStringList m_domainList;
     bool m_isClickjackingProtectionEnabled;
     bool m_isCSRFProtectionEnabled;
+    bool m_isHostHeaderValidationEnabled;
     bool m_isHttpsEnabled;
+    QString m_contentSecurityPolicy;
 };
