@@ -24,6 +24,8 @@
 
 torrentsTable = new TorrentsTable();
 torrentPeersTable = new TorrentPeersTable();
+searchResultsTable = new SearchResultsTable();
+searchPluginsTable = new SearchPluginsTable();
 
 var updatePropertiesPanel = function() {};
 
@@ -36,7 +38,8 @@ var updateTorrentFilesData = function() {};
 var updateMainData = function() {};
 var alternativeSpeedLimits = false;
 var queueing_enabled = true;
-var syncMainDataTimerPeriod = 1500;
+var serverSyncMainDataInterval = 1500;
+var customSyncMainDataInterval = null;
 
 var clipboardEvent;
 
@@ -66,6 +69,10 @@ function genHash(string) {
     return hash;
 }
 
+function getSyncMainDataInterval() {
+    return customSyncMainDataInterval ? customSyncMainDataInterval : serverSyncMainDataInterval;
+}
+
 window.addEvent('load', function() {
 
     var saveColumnSizes = function() {
@@ -76,8 +83,9 @@ window.addEvent('load', function() {
     };
 
     window.addEvent('resize', function() {
-        // Resizing might takes some time.
-        saveColumnSizes.delay(200);
+        // only save sizes if the columns are visible
+        if (!$("mainColumn").hasClass("invisible"))
+            saveColumnSizes.delay(200); // Resizing might takes some time.
     });
 
     /*MochaUI.Desktop = new MochaUI.Desktop();
@@ -87,24 +95,40 @@ window.addEvent('load', function() {
     });*/
     MochaUI.Desktop.initialize();
 
-    var filt_w = localStorage.getItem('filters_width');
-    if ($defined(filt_w))
-        filt_w = filt_w.toInt();
-    else
-        filt_w = 120;
-    new MochaUI.Column({
-        id: 'filtersColumn',
-        placement: 'left',
-        onResize: saveColumnSizes,
-        width: filt_w,
-        resizeLimit: [100, 300]
-    });
-    new MochaUI.Column({
-        id: 'mainColumn',
-        placement: 'main',
-        width: null,
-        resizeLimit: [100, 300]
-    });
+    var buildTransfersTab = function() {
+        var filt_w = localStorage.getItem('filters_width');
+        if ($defined(filt_w))
+            filt_w = filt_w.toInt();
+        else
+            filt_w = 120;
+        new MochaUI.Column({
+            id: 'filtersColumn',
+            placement: 'left',
+            onResize: saveColumnSizes,
+            width: filt_w,
+            resizeLimit: [1, 300]
+        });
+
+        new MochaUI.Column({
+            id: 'mainColumn',
+            placement: 'main'
+        });
+    };
+
+    var buildSearchTab = function() {
+        new MochaUI.Column({
+            id: 'searchTabColumn',
+            placement: 'main',
+            width: null
+        });
+
+        // start off hidden
+        $("searchTabColumn").addClass("invisible");
+    };
+
+    buildTransfersTab();
+    buildSearchTab();
+    MochaUI.initializeTabs('mainWindowTabsList');
 
     setCategoryFilter = function(hash) {
         selected_category = hash;
@@ -186,6 +210,15 @@ window.addEvent('load', function() {
         $('speedInBrowserTitleBarLink').firstChild.style.opacity = '0';
 
     // After showing/hiding the toolbar + status bar
+    var showSearchEngine = localStorage.getItem('show_search_engine') === "true";
+    if (!showSearchEngine) {
+        // uncheck menu option
+        $('showSearchEngineLink').firstChild.style.opacity = '0';
+        // hide tabs
+        $('mainWindowTabs').addClass('invisible');
+    }
+
+    // After Show Top Toolbar
     MochaUI.Desktop.setDesktopSize();
 
     var syncMainDataLastResponseId = 0;
@@ -301,7 +334,7 @@ window.addEvent('load', function() {
     var syncMainData = function() {
         var url = new URI('api/v2/sync/maindata');
         url.setData('rid', syncMainDataLastResponseId);
-        var request = new Request.JSON({
+        new Request.JSON({
             url: url,
             noCache: true,
             method: 'get',
@@ -315,6 +348,7 @@ window.addEvent('load', function() {
             onSuccess: function(response) {
                 $('error_div').set('html', '');
                 if (response) {
+                    clearTimeout(torrentsFilterInputTimer);
                     var torrentsTableSelectedRows;
                     var update_categories = false;
                     var full_update = (response['full_update'] === true);
@@ -393,7 +427,7 @@ window.addEvent('load', function() {
                         torrentsTable.reselectRows(torrentsTableSelectedRows);
                 }
                 clearTimeout(syncMainDataTimer);
-                syncMainDataTimer = syncMainData.delay(syncMainDataTimerPeriod);
+                syncMainDataTimer = syncMainData.delay(getSyncMainDataInterval());
             }
         }).send();
     };
@@ -421,6 +455,7 @@ window.addEvent('load', function() {
         }
         else
             document.title = "qBittorrent ${VERSION} QBT_TR(Web UI)QBT_TR[CONTEXT=OptionsDialog]";
+        $('freeSpaceOnDisk').set('html', 'QBT_TR(Free space: %1)QBT_TR[CONTEXT=HttpServer]'.replace("%1", friendlyUnit(serverState.free_space_on_disk)));
         $('DHTNodes').set('html', 'QBT_TR(DHT: %1 nodes)QBT_TR[CONTEXT=StatusBar]'.replace("%1", serverState.dht_nodes));
 
         // Statistics dialog
@@ -473,9 +508,7 @@ window.addEvent('load', function() {
             updateAltSpeedIcon(alternativeSpeedLimits);
         }
 
-        syncMainDataTimerPeriod = serverState.refresh_interval;
-        if (syncMainDataTimerPeriod < 500)
-            syncMainDataTimerPeriod = 500;
+        serverSyncMainDataInterval = Math.max(serverState.refresh_interval, 500);
     };
 
     var updateAltSpeedIcon = function(enabled) {
@@ -544,8 +577,89 @@ window.addEvent('load', function() {
         processServerState();
     });
 
+    $('showSearchEngineLink').addEvent('click', function(e) {
+        showSearchEngine = !showSearchEngine;
+        localStorage.setItem('show_search_engine', showSearchEngine.toString());
+        if (showSearchEngine) {
+            $('showSearchEngineLink').firstChild.style.opacity = '1';
+            $('mainWindowTabs').removeClass('invisible');
+
+            addMainWindowTabsEventListener();
+            if (!MochaUI.Panels.instances.SearchPanel)
+                addSearchPanel();
+        }
+        else {
+            $('showSearchEngineLink').firstChild.style.opacity = '0';
+            $('mainWindowTabs').addClass('invisible');
+            $("transfersTabLink").click();
+
+            removeMainWindowTabsEventListener();
+        }
+    });
+
     $('StatisticsLink').addEvent('click', StatisticsLinkFN);
 
+    // main window tabs
+
+    var showTransfersTab = function() {
+        $("filtersColumn").removeClass("invisible");
+        $("filtersColumn_handle").removeClass("invisible");
+        $("mainColumn").removeClass("invisible");
+
+        customSyncMainDataInterval = null;
+        clearTimeout(syncMainDataTimer);
+        syncMainDataTimer = syncMainData.delay(100);
+
+        hideSearchTab();
+    };
+
+    var hideTransfersTab = function() {
+        $("filtersColumn").addClass("invisible");
+        $("filtersColumn_handle").addClass("invisible");
+        $("mainColumn").addClass("invisible");
+        MochaUI.Desktop.resizePanels();
+    };
+
+    var showSearchTab = function() {
+        $("searchTabColumn").removeClass("invisible");
+        customSyncMainDataInterval = 30000;
+        hideTransfersTab();
+    };
+
+    var hideSearchTab = function() {
+        $("searchTabColumn").addClass("invisible");
+        MochaUI.Desktop.resizePanels();
+    };
+
+    var addMainWindowTabsEventListener = function() {
+        $('transfersTabLink').addEvent('click', showTransfersTab);
+        $('searchTabLink').addEvent('click', showSearchTab);
+    };
+
+    var removeMainWindowTabsEventListener = function() {
+        $('transfersTabLink').removeEvent('click', showTransfersTab);
+        $('searchTabLink').removeEvent('click', showSearchTab);
+    };
+
+    var addSearchPanel = function() {
+        new MochaUI.Panel({
+            id : 'SearchPanel',
+            title : 'Search',
+            header : false,
+            padding : {
+                top : 0,
+                right : 0,
+                bottom : 0,
+                left : 0
+            },
+            loadMethod : 'xhr',
+            contentURL : 'search.html',
+            content: '',
+            column : 'searchTabColumn',
+            height : null
+        });
+    };
+
     new MochaUI.Panel({
         id: 'transferList',
         title: 'Panel',
@@ -659,6 +773,25 @@ window.addEvent('load', function() {
         column: 'mainColumn',
         height: prop_h
     });
+
+    var prevTorrentsFilterValue;
+    var torrentsFilterInputTimer = null;
+    // listen for changes to torrentsFilterInput
+    $('torrentsFilterInput').addEvent('input', function() {
+        var value = $('torrentsFilterInput').get("value");
+        if (value !== prevTorrentsFilterValue) {
+            prevTorrentsFilterValue = value;
+            clearTimeout(torrentsFilterInputTimer);
+            torrentsFilterInputTimer = setTimeout(function() {
+                torrentsTable.updateTable(false);
+            }, 400);
+        }
+    });
+
+    if (showSearchEngine) {
+        addMainWindowTabsEventListener();
+        addSearchPanel();
+    }
 });
 
 function closeWindows() {
@@ -671,21 +804,18 @@ function setupCopyEventHandler() {
 
     clipboardEvent = new ClipboardJS('.copyToClipboard', {
         text: function(trigger) {
-            var textToCopy;
-
             switch (trigger.id) {
                 case "CopyName":
-                    textToCopy = copyNameFN();
-                    break;
+                    return copyNameFN();
                 case "CopyMagnetLink":
-                    textToCopy = copyMagnetLinkFN();
-                    break;
+                    return copyMagnetLinkFN();
                 case "CopyHash":
-                    textToCopy = copyHashFN();
-                    break;
+                    return copyHashFN();
+                case "copyDescriptionPageUrl":
+                    return copySearchTorrentUrl();
+                default:
+                    return "";
             }
-
-            return textToCopy;
         }
     });
 }
@@ -721,13 +851,13 @@ var loadTorrentPeersData = function() {
         syncTorrentPeersLastResponseId = 0;
         torrentPeersTable.clear();
         clearTimeout(loadTorrentPeersTimer);
-        loadTorrentPeersTimer = loadTorrentPeersData.delay(syncMainDataTimerPeriod);
+        loadTorrentPeersTimer = loadTorrentPeersData.delay(getSyncMainDataInterval());
         return;
     }
     var url = new URI('api/v2/sync/torrentPeers');
     url.setData('rid', syncTorrentPeersLastResponseId);
     url.setData('hash', current_hash);
-    var request = new Request.JSON({
+    new Request.JSON({
         url: url,
         noCache: true,
         method: 'get',
@@ -775,7 +905,7 @@ var loadTorrentPeersData = function() {
                 torrentPeersTable.clear();
             }
             clearTimeout(loadTorrentPeersTimer);
-            loadTorrentPeersTimer = loadTorrentPeersData.delay(syncMainDataTimerPeriod);
+            loadTorrentPeersTimer = loadTorrentPeersData.delay(getSyncMainDataInterval());
         }
     }).send();
 };
