@@ -875,7 +875,7 @@
     </message>
     <message>
         <source>%G: Tags (seperated by comma)</source>
-        <translation>%G: Mærkatet (separeret af komma)</translation>
+        <translation type="vanished">%G: Mærkatet (separeret af komma)</translation>
     </message>
     <message>
         <source>%F: Content path (same as root path for multifile torrent)</source>
@@ -1041,6 +1041,10 @@
         <source>When adding a torrent</source>
         <translation>Når en torrent tilføjes</translation>
     </message>
+    <message>
+        <source>%G: Tags (separated by comma)</source>
+        <translation type="unfinished" />
+    </message>
 </context>
 <context>
     <name>PeerListWidget</name>
