@@ -877,10 +877,6 @@
         <source>%L: Category</source>
         <translation type="unfinished" />
     </message>
-    <message>
-        <source>%G: Tags (seperated by comma)</source>
-        <translation type="unfinished" />
-    </message>
     <message>
         <source>%F: Content path (same as root path for multifile torrent)</source>
         <translation type="unfinished" />
@@ -1041,6 +1037,10 @@
         <source>When adding a torrent</source>
         <translation type="unfinished" />
     </message>
+    <message>
+        <source>%G: Tags (separated by comma)</source>
+        <translation type="unfinished" />
+    </message>
 </context>
 <context>
     <name>PeerListWidget</name>
